# dask-ngs

[![Actions Status][actions-badge]][actions-link]
[![Documentation Status][rtd-badge]][rtd-link]

[![PyPI version][pypi-version]][pypi-link]
<!-- [![Conda-Forge][conda-badge]][conda-link] -->
[![PyPI platforms][pypi-platforms]][pypi-link]

[![GitHub Discussion][github-discussions-badge]][github-discussions-link]

<!-- prettier-ignore-start -->
[actions-badge]:            https://github.com/abdenlab/dask-ngs/workflows/CI/badge.svg
[actions-link]:             https://github.com/abdenlab/dask-ngs/actions
[conda-badge]:              https://img.shields.io/conda/vn/conda-forge/dask-ngs
[conda-link]:               https://github.com/conda-forge/dask-ngs-feedstock
[github-discussions-badge]: https://img.shields.io/static/v1?label=Discussions&message=Ask&color=blue&logo=github
[github-discussions-link]:  https://github.com/abdenlab/dask-ngs/discussions
[pypi-link]:                https://pypi.org/project/dask-ngs/
[pypi-platforms]:           https://img.shields.io/pypi/pyversions/dask-ngs
[pypi-version]:             https://img.shields.io/pypi/v/dask-ngs
[rtd-badge]:                https://readthedocs.org/projects/dask-ngs/badge/?version=latest
[rtd-link]:                 https://dask-ngs.readthedocs.io/en/latest/?badge=latest
<!-- prettier-ignore-end -->
